=======
Credits
=======

Development Lead
----------------

* Nathan Xue <xue.nathanv1.0@gmail.com>

CFSAN Bioinformatics Team
-------------------------

* Nathan Xue <xue.nathanv1.0@gmail.com>

External Contributors
---------------------

None yet. Why not be the first?
